==> cobs-0.8.tgz: cobs-0.8/gb/search.php <==
<?php 
 require("config.php");
 require("dbconfig.php");
 require("lang.php");
 /**** ñ ********/
  //ҳ
 $PROGNAME="search.php";
 $READPROGNAME="read.php";
 /************* GET  ***************/
  $VERSION=$_REQUEST["VERSION"];//汾
  $strongflag=(int) $_REQUEST["strongflag"];//ҪҪshow strong 趨prefer
  $TABFLAG=(int) $_REQUEST["TABFLAG"];//չʾʽ 趨 prefer
  $orig=(int) $_REQUEST["orig"];      //0 1:ϣı 2:ϣı
  $keyword=tranbig5($_REQUEST["keyword"]);      //ѯ
  $RANGE=(int) $_REQUEST["RANGE"];    //ѯģʽ 0ȫ 1Լ 2:Լ 3:Χ
  $range_bid=(int) $_REQUEST["range_bid"]; //Χѯ֮ʼ
  $range_eid=(int) $_REQUEST["range_eid"]; //Χѯ֮

  //Queryָ
 if (strlen($VERSION)==0) $VERSION="unv";
 $oldv=$VERSION;
 if (strcmp($VERSION,"kjv")==0) $stronged=1;
 elseif (strcmp($VERSION,"unv")==0) $stronged=1;
 else $stronged=0;
 $oldkeyword=$keyword;
 if ($orig==1)//ȷ Greek strong number
 {
	if ($stronged==0) 
	{
		echo "<h2>˰汾֧ԮStrong number <h2>";
		exit;
	}
	// ԼSN > 5626ϾWTG
	if ( ((int) $keyword) > 5626)
		$revkey="({$keyword})";
	else    $revkey="&lt;{$keyword}&gt;";
	$keyword=sprintf("G%d>",$keyword);
	$sstrong=1;
 }
 elseif ($orig==2)//ȷ Heb strong number
 {
	if ($stronged==0) 
	{
		echo "<h2>˰汾֧ԮStrong number <h2>";
		exit;
	}
	// ԼSN >= 8680 ϾWTG
	if ( ((int) $keyword) >= 8680)
		$revkey="({$keyword})";
	else    $revkey="&lt;0{$keyword}&gt;";
	$keyword=sprintf("H0%d>",$keyword);
	$sstrong=1;
 }
 else //İ汾ûstrong numberİ汾
  {
	$sstrong=0;
 	if (strcmp($VERSION,"kjv")==0) $VERSION="nstrkjv";
 	elseif (strcmp($VERSION,"unv")==0) $VERSION="nstrunv";
 	$revkey=$keyword;
  }
 /******* ѯΧ *********/
 if (($range_eid>0) || ($range_bid>0)) $RANGE=3; //ѡǵ״
 switch ($RANGE)
 {
	case 0: $RANGELIMIT=""; break; //ʥ
	case 1: $RANGELIMIT="and main.id>39"; break; //Լ
	case 2: $RANGELIMIT="and main.id<40"; break; //Լ
	case 3: 
		if ($range_eid<$range_bid) //˳
			{
				$idtmp=$range_eid;
				$range_eid=$range_bid;
				$range_bid=$idtmp;
			}
		if (($range_eid ==0)&&($range_bid ==0)) //ûѡʥ
			{
				$range_bid=1;
				$range_eid=66;
			}
		if ($range_bid==0) $range_bid=$range_eid; //ûѡһ
		$RANGELIMIT="and main.id>=$range_bid and main.id<=$range_eid";
		break;
 }
 if ($updatemode)
 $QUERY="select main.chineses, $VERSION.chap||':'||$VERSION.sec,$VERSION.txt,$VERSION.id,$VERSION.username from $VERSION,main where main.engs=$VERSION.engs $RANGELIMIT and $VERSION.txt like '%$keyword%' order by $VERSION.id"; 
 else
 $QUERY="select main.chineses, $VERSION.chap||':'||$VERSION.sec,$VERSION.txt,$VERSION.id from $VERSION,main where main.engs=$VERSION.engs $RANGELIMIT and $VERSION.txt like '%$keyword%' order by $VERSION.id"; 
  //Tableر
 $tabout="border=1";
  //ҳı
  //ѯϱͷ
 if ($updatemode)
 	$THEADER=array("","½","","");
 else
 	$THEADER=array("","½","");
  //ÿһҳı
 $PGNUM=50;
 // Primary Key	
 $PKEY="oid";
 $KEYCOLOR="\"#FF0000\"";
 $COLOR="\"#000000\"";
 require("strong.php");
 $db_conn=db_connect("host=localhost dbname=$DBNAME");
 db_set_encoding($db_conn,"BIG5");
 if (strlen($keyword)==0)
 {
	echo "ûκβѯϣһΣ\n";
 	exit;
 }
 /******** ʼϿ ********/
 $result=db_exec($db_conn,$QUERY);
 if (!$result){
                        echo "Ͽѯ $QUERY !";
                        exit;
 }
 $numrow=db_NumRows($result);  
 /****** ǳ *********/
 if ($numrow>500)
   {
   	echo " $numrow ʣ̫ˣ޸Ĳѯٲ飡";
	exit;
   }
 if ($numrow==0)
   {
   	echo "鲻κϣ޸Ĳѯٲ飡";
	exit;
   }
 $numfield=db_NumFields($result);
 /******** ӡ ********/
   echo "<head><title>Bible Search Result: $oldkeyword</title>\n";
 echo "<meta http-equiv=\"Content-Type\" CONTENT=\"text/html; charset=GB2312\">";
 echo "</head>\n";
 $PGEND=$PGBEG+$PGNUM-1;
 if ($PGEND>($numrow-1))
 {
	$PGEND=$numrow-1;
 }
 if ($PGBEG>=$PGNUM)
 {
   $a=$PGBEG-$PGNUM;
   echo "<center><form method=\"POST\" action=\"$PROGNAME\">\n";
   echo "<input type=\"hidden\" name=\"PGBEG\" value=\"$a\">\n";
   echo "<input type=\"hidden\" name=\"VERSION\" value=\"$oldv\">\n";
   echo "<input type=\"hidden\" name=\"RANGE\" value=\"$RANGE\">\n";
   echo "<input type=\"hidden\" name=\"range_bid\" value=\"$range_bid\">\n";
   echo "<input type=\"hidden\" name=\"range_eid\" value=\"$range_eid\">\n";
   echo "<input type=\"hidden\" name=\"TABFLAG\" value=\"$TABFLAG\">\n";
   echo "<input type=\"hidden\" name=\"strongflag\" value=\"$strongflag\">\n";
   echo "<input type=\"hidden\" name=\"keyword\" value=\"$oldkeyword\">\n";
   echo "<input type=\"hidden\" name=\"orig\" value=\"$orig\">\n";
   echo "<input type=\"submit\" name=\"submit1\" value=\"һҳ\">\n";
   echo "</form></center>\n";
 }
 $fpt=$PGBEG+1;
 echo "ܹ $numrow ϣĿǰɵ $fpt ʿʼӡ<br>\n";
 if ($TABFLAG)
 {
 	echo "<FONT COLOR=$COLOR><table $tabout>\n<tr>";
	if ($updatemode) $fpcnt=4;
        else $fpcnt=3;
 	for ($fpt=0;$fpt<$fpcnt;$fpt++)
 	{
    		$special=htmlspecialchars($THEADER[$fpt]);//Ԫ
    		echo "<td align=center>$special</td>";
 	}
 	echo "</tr>";
 }
 /****ӡ *****/
 for($a=$PGBEG;$a<=$PGEND;$a++)
   {
      if ($TABFLAG)
      {
         echo "<tr>";
      }
      $ARAW=db_fetch_row($result,$a); //ȡһʼ¼
      if ($TABFLAG)
      {
        $special=htmlspecialchars(trim($ARAW[0]));//Ԫ
      	echogb("<td>$special</td>");
        $special=htmlspecialchars($ARAW[1]);//Ԫ
        echo "<td><a href=\"$READPROGNAME?id=$ARAW[3]&VERSION=$oldv&strongflag=$strongflag&TABFLAG=$TABFLAG\" target=\"READ\">$special</a></td>";
        if ($updatemode) echo "<td>$ARAW[4]</td>";
      }
      else //ޱ
      {
	$special1=htmlspecialchars($ARAW[0]);//Ԫ
        $special=htmlspecialchars($ARAW[1]);//Ԫ
      echo "<a href=\"$READPROGNAME?id=$ARAW[3]&VERSION=$oldv&strongflag=$strongflag&TABFLAG=$TABFLAG\" target=\"READ\">$special1 $special</a>  ";
        if ($updatemode) echo "<td>$ARAW[4]</td>";
      }
      /*********/
      $bibletex=$ARAW[2];
      if ($stronged) $bibletex=procstrong($strongflag,$bibletex);	
      if ($TABFLAG) echo "<td>";
      $pos=strpos($bibletex,$revkey);
      while (!($pos===false))
      {
	$pretex=substr($bibletex,0,$pos);
        $newpos=$pos+strlen($revkey);
	$bibletex=substr($bibletex,$newpos);
        //echo "BIBLE=$bibletex";
	if ($stronged) $special=$pretex;
	else $special=htmlspecialchars($pretex);
	
        echogb("$special</font><font color=$KEYCOLOR>$revkey</font><font color=$COLOR>");
        $pos=strpos($bibletex,$revkey);
      }
      if ($stronged) $special=$bibletex;
      else $special=htmlspecialchars($bibletex);
      if ($TABFLAG)
		echogb("$special</td>");
      else 
		echogb("$special<br>");
      if ($TABFLAG)
      		echo "</tr>\n";
   }
   if ($TABFLAG)
   		echo "</table></font>\n";
 if ($PGEND<($numrow-1))
 {
   $a=$PGEND+1;
   echo "<center><form method=\"POST\" action=\"$PROGNAME\">\n";
   echo "<input type=\"hidden\" name=\"PGBEG\" value=\"$a\">\n";
   echo "<input type=\"hidden\" name=\"VERSION\" value=\"$oldv\">\n";
   echo "<input type=\"hidden\" name=\"RANGE\" value=\"$RANGE\">\n";
   echo "<input type=\"hidden\" name=\"range_bid\" value=\"$range_bid\">\n";
   echo "<input type=\"hidden\" name=\"range_eid\" value=\"$range_eid\">\n";
   echo "<input type=\"hidden\" name=\"keyword\" value=\"$oldkeyword\">\n";
   echo "<input type=\"hidden\" name=\"TABFLAG\" value=\"$TABFLAG\">\n";
   echo "<input type=\"hidden\" name=\"orig\" value=\"$orig\">\n";
   echo "<input type=\"hidden\" name=\"strongflag\" value=\"$strongflag\">\n";
   echo "<input type=\"submit\" name=\"submit1\" value=\"һҳ\">\n";
   echo "</form></center>\n";
 }
  /***** ҳ ****/
  $a=0;
  $poldkeyword=urlencode($oldkeyword);
  echo "<center>ҳΣ&nbsp;&nbsp;";
  for ($recpt=0;$recpt<=$numrow-1;$recpt=$recpt+$PGNUM)
  {
	$a=$a+1;
	if ($recpt!=$PGBEG) //Ǳҳ
	{
	 echo "&nbsp;<a href=\"$PROGNAME?PGBEG={$recpt}&VERSION={$oldv}&keyword={$poldkeyword}&TABFLAG={$TABFLAG}&orig={$orig}&strongflag={$strongflag}&RANGE={$RANGE}&range_bid={$range_bid}&range_eid={$range_eid}\">{$a}</a>&nbsp;\n";
	}
	else echo "&nbsp;<font color=\"red\">{$a}</font>&nbsp;";
  }
  echo "</center>";
   echo "<center><a href=\"$RETURNADD1\">²ѯ</a></center><br>\n";
   if ($stronged)
   {
echo "<hr>\nKJV + Strongs and lexicons were adapted from the Online Bible. It used by permission and are copyrighted by Timnathserah Inc.";
   }

?>

==> cobs-0.9.tgz: cobs-0.9/gb/search.php <==
<?php 
 require("config.php");
 require("dbconfig.php");
 require("lang.php");
 /**** ñ ********/
  //ҳ
 $PROGNAME="search.php";
 $READPROGNAME="read.php";
 /************* GET  ***************/
  $VERSION=$_REQUEST["VERSION"];//汾
  $strongflag=(int) $_REQUEST["strongflag"];//ҪҪshow strong 趨prefer
  $TABFLAG=(int) $_REQUEST["TABFLAG"];//չʾʽ 趨 prefer
  $orig=(int) $_REQUEST["orig"];      //0 1:ϣı 2:ϣı
  $keyword=trim(tranbig5($_REQUEST["keyword"]));      //ѯ
  $RANGE=(int) $_REQUEST["RANGE"];    //ѯģʽ 0ȫ 1Լ 2:Լ 3:Χ
  $range_bid=(int) $_REQUEST["range_bid"]; //Χѯ֮ʼ
  $range_eid=(int) $_REQUEST["range_eid"]; //Χѯ֮
  //Queryָ
 if (strlen($VERSION)==0) $VERSION="unv";
 $oldv=$VERSION;
 if (strcmp($VERSION,"kjv")==0) $stronged=1;
 elseif (strcmp($VERSION,"unv")==0) $stronged=1;
 else $stronged=0;
 $oldkeyword=$keyword;
 if ($orig==1)//ȷ Greek strong number
 {
	if ($stronged==0) 
	{
		echo "<h2>˰汾֧ԮStrong number <h2>";
		exit;
	}
	// ԼSN > 5626ϾWTG
	if ( ((int) $keyword) > 5626)
		$revkey="({$keyword})";
	else    $revkey="&lt;{$keyword}&gt;";
	$keyword=sprintf("G%d>",$keyword);
	$sstrong=1;
 }
 elseif ($orig==2)//ȷ Heb strong number
 {
	if ($stronged==0) 
	{
		echo "<h2>˰汾֧ԮStrong number <h2>";
		exit;
	}
	// ԼSN >= 8680 ϾWTG
	if ( ((int) $keyword) >= 8680)
		$revkey="({$keyword})";
	else    $revkey="&lt;0{$keyword}&gt;";
	$keyword=sprintf("H0%d>",$keyword);
	$sstrong=1;
 }
 else //İ汾ûstrong numberİ汾
  {
	$sstrong=0;
 	if (strcmp($VERSION,"kjv")==0) $VERSION="nstrkjv";
 	elseif (strcmp($VERSION,"unv")==0) $VERSION="nstrunv";
 	$revkey=$keyword;
  }
 /******* ѯΧ *********/
 if (($range_eid>0) || ($range_bid>0)) $RANGE=3; //ѡǵ״
 switch ($RANGE)
 {
	case 0: $RANGELIMIT=""; break; //ʥ
	case 1: $RANGELIMIT="and main.id>39"; break; //Լ
	case 2: $RANGELIMIT="and main.id<40"; break; //Լ
	case 3: 
		if ($range_eid<$range_bid) //˳
			{
				$idtmp=$range_eid;
				$range_eid=$range_bid;
				$range_bid=$idtmp;
			}
		if (($range_eid ==0)&&($range_bid ==0)) //ûѡʥ
			{
				$range_bid=1;
				$range_eid=66;
			}
		if ($range_bid==0) $range_bid=$range_eid; //ûѡһ
		$RANGELIMIT="and main.id>=$range_bid and main.id<=$range_eid";
		break;
 }
 /******* ߼ѯ *********/
 $keyword=str_replace("("," ( ",$keyword);
 $keyword=str_replace(")"," ) ",$keyword);
 $KEYLIMIT=$keyword;
 $keyptok=split(" ",$keyword); //Queryִ
 $keycnt=count($keyptok);
 $keyi=0;
  //˿ token
 for ($keypt=0;$keypt<$keycnt;$keypt=$keypt+1)
 {
     if (strlen($keyptok[$keypt])==0) continue;
     else $keytok[$keyi++]=$keyptok[$keypt];
 }
 $keycnt=count($keytok);
 $KEYLIMIT="";
 for ($keypt=0;$keypt<$keycnt;$keypt=$keypt+1)
 {
     if (strcasecmp($keytok[$keypt],"not")==0) 
	{
		$KEYLIMIT=$KEYLIMIT." $keytok[$keypt] ";
		continue;
	}
     if (strcasecmp($keytok[$keypt],")")==0) 
	{
		$KEYLIMIT=$KEYLIMIT." $keytok[$keypt] ";
		continue;
	}
     if (strcasecmp($keytok[$keypt],"(")==0) 
	{
		$KEYLIMIT=$KEYLIMIT." $keytok[$keypt] ";
		continue;
	}
     if (strcasecmp($keytok[$keypt],"and")==0) 
	{
		$KEYLIMIT=$KEYLIMIT." $keytok[$keypt] ";
		continue;
	}
     if (strcasecmp($keytok[$keypt],"or")==0) 
	{
		$KEYLIMIT=$KEYLIMIT." $keytok[$keypt] ";
		continue;
	}
     $akeypt=$keypt+1;//LOOK AHEAD POINTER	
     if (strcasecmp($keytok[$akeypt],"and")!=0 //and 
	 && $akeypt < $keycnt
         && strcasecmp($keytok[$akeypt],"or")!=0 //or
         && strcasecmp($keytok[$akeypt],")")!=0 //)
         && strcasecmp($keytok[$akeypt],"not")!=0) //not
     {
         $nkey="$VERSION.txt like '%$keytok[$keypt]%' and ";
	 $KEYLIMIT=$KEYLIMIT.$nkey;
         // $KEYLIMIT=str_replace($keytok[$keypt],$nkey,$KEYLIMIT);
     }
     else
    {
         $nkey="$VERSION.txt like '%$keytok[$keypt]%'";
	 $KEYLIMIT=$KEYLIMIT.$nkey;
         //$KEYLIMIT=str_replace($keytok[$keypt],$nkey,$KEYLIMIT);
    }
 } 
  //ȷϲѯĹؼ
 if ($orig==0) //
 {
    $keyi=0;
    $keyptok=array();
    for ($keypt=0;$keypt<$keycnt;$keypt=$keypt+1)
    {
     	if (strcasecmp($keytok[$keypt],"not")==0) continue;
     	if (strcasecmp($keytok[$keypt],")")==0) continue;
     	if (strcasecmp($keytok[$keypt],"(")==0) continue;
     	if (strcasecmp($keytok[$keypt],"and")==0) continue;
     	if (strcasecmp($keytok[$keypt],"or")==0) continue;
     	$keyptok[$keyi++]=$keytok[$keypt];
      }
 	$keycnt=count($keyptok);
 }
 else //SN
 {
     $keyptok=array("{$revkey}");
     $keycnt=1;
 }

 if ($updatemode)
 $QUERY="select main.chineses, $VERSION.chap||':'||$VERSION.sec,$VERSION.txt,$VERSION.id,$VERSION.username from $VERSION,main where main.engs=$VERSION.engs $RANGELIMIT and $KEYLIMIT order by $VERSION.id"; 
 else
 $QUERY="select main.chineses, $VERSION.chap||':'||$VERSION.sec,$VERSION.txt,$VERSION.id from $VERSION,main where main.engs=$VERSION.engs $RANGELIMIT and $KEYLIMIT order by $VERSION.id"; 
  //Tableر
 $tabout="border=1";
  //ҳı
  //ѯϱͷ
 if ($updatemode)
 	$THEADER=array("","½","","");
 else
 	$THEADER=array("","½","");
  //ÿһҳı
 $PGNUM=50;
 // Primary Key	
 $PKEY="oid";
 $KEYCOLOR="\"#FF0000\"";
 $COLOR="\"#000000\"";
 require("strong.php");
 $db_conn=db_connect("host=localhost dbname=$DBNAME");
 db_set_encoding($db_conn,"BIG5");
 if (strlen($keyword)==0)
 {
	echo "ûκβѯϣһΣ\n";
 	exit;
 }
 /******** ʼϿ ********/
 $result=db_exec($db_conn,$QUERY);
 if (!$result){
                        echo "Ͽѯ $QUERY !";
                        exit;
 }
 $numrow=db_NumRows($result);  
 /****** ǳ *********/
 if ($numrow>500)
   {
   	echo " $numrow ʣ̫ˣ޸Ĳѯٲ飡";
	exit;
   }
 if ($numrow==0)
   {
   	echo "鲻κϣ޸Ĳѯٲ飡";
	exit;
   }
 $numfield=db_NumFields($result);
 /******** ӡ ********/
   echo "<head><title>Bible Search Result: $oldkeyword</title>\n";
 echo "<meta http-equiv=\"Content-Type\" CONTENT=\"text/html; charset=GB2312\">";
 echo "</head>\n";
 $PGEND=$PGBEG+$PGNUM-1;
 if ($PGEND>($numrow-1))
 {
	$PGEND=$numrow-1;
 }
 if ($PGBEG>=$PGNUM)
 {
   $a=$PGBEG-$PGNUM;
   echo "<center><form method=\"POST\" action=\"$PROGNAME\">\n";
   echo "<input type=\"hidden\" name=\"PGBEG\" value=\"$a\">\n";
   echo "<input type=\"hidden\" name=\"VERSION\" value=\"$oldv\">\n";
   echo "<input type=\"hidden\" name=\"RANGE\" value=\"$RANGE\">\n";
   echo "<input type=\"hidden\" name=\"range_bid\" value=\"$range_bid\">\n";
   echo "<input type=\"hidden\" name=\"range_eid\" value=\"$range_eid\">\n";
   echo "<input type=\"hidden\" name=\"TABFLAG\" value=\"$TABFLAG\">\n";
   echo "<input type=\"hidden\" name=\"strongflag\" value=\"$strongflag\">\n";
   echo "<input type=\"hidden\" name=\"keyword\" value=\"$oldkeyword\">\n";
   echo "<input type=\"hidden\" name=\"orig\" value=\"$orig\">\n";
   echo "<input type=\"submit\" name=\"submit1\" value=\"һҳ\">\n";
   echo "</form></center>\n";
 }
 $fpt=$PGBEG+1;
 echo "ܹ $numrow ϣĿǰɵ $fpt ʿʼӡ<br>\n";
 if ($TABFLAG)
 {
 	echo "<FONT COLOR=$COLOR><table $tabout>\n<tr>";
	if ($updatemode) $fpcnt=4;
        else $fpcnt=3;
 	for ($fpt=0;$fpt<$fpcnt;$fpt++)
 	{
    		$special=htmlspecialchars($THEADER[$fpt]);//Ԫ
    		echo "<td align=center>$special</td>";
 	}
 	echo "</tr>";
 }
 /****ӡ *****/
 for($a=$PGBEG;$a<=$PGEND;$a++)
   {
      if ($TABFLAG)
      {
         echo "<tr>";
      }
      $ARAW=db_fetch_row($result,$a); //ȡһʼ¼
      if ($TABFLAG)
      {
        $special=htmlspecialchars(trim($ARAW[0]));//Ԫ
      	echogb("<td>$special</td>");
        $special=htmlspecialchars($ARAW[1]);//Ԫ
        echo "<td><a href=\"$READPROGNAME?id=$ARAW[3]&VERSION=$oldv&strongflag=$strongflag&TABFLAG=$TABFLAG\" target=\"READ\">$special</a></td>";
        if ($updatemode) echo "<td>$ARAW[4]</td>";
      }
      else //ޱ
      {
	$special1=htmlspecialchars($ARAW[0]);//Ԫ
        $special=htmlspecialchars($ARAW[1]);//Ԫ
      echo "<a href=\"$READPROGNAME?id=$ARAW[3]&VERSION=$oldv&strongflag=$strongflag&TABFLAG=$TABFLAG\" target=\"READ\">$special1 $special</a>  ";
        if ($updatemode) echo "<td>$ARAW[4]</td>";
      }
      /*********/
      $bibletex=$ARAW[2];
      if ($stronged) $bibletex=procstrong($strongflag,$bibletex);	
      if ($TABFLAG) echo "<td>";
      //show ɫؼ
      for ($keypt=0;$keypt<$keycnt;$keypt=$keypt+1)
      {
         $outputstr="</font><font color=$KEYCOLOR>$keyptok[$keypt]</font><font color=$COLOR>";
	$bibletex=str_replace($keyptok[$keypt],$outputstr,$bibletex);
      }
      //echo $outputstr;
      if ($stronged) $special=$bibletex;
      else $special=htmlspecialchars($bibletex);
      if ($TABFLAG)
		echogb ("$special</td>");
      else 
		echogb ("$special<br>");
      if ($TABFLAG)
      		echo "</tr>\n";
   }
   if ($TABFLAG)
   		echo "</table></font>\n";
 if ($PGEND<($numrow-1))
 {
   $a=$PGEND+1;
   echo "<center><form method=\"POST\" action=\"$PROGNAME\">\n";
   echo "<input type=\"hidden\" name=\"PGBEG\" value=\"$a\">\n";
   echo "<input type=\"hidden\" name=\"VERSION\" value=\"$oldv\">\n";
   echo "<input type=\"hidden\" name=\"RANGE\" value=\"$RANGE\">\n";
   echo "<input type=\"hidden\" name=\"range_bid\" value=\"$range_bid\">\n";
   echo "<input type=\"hidden\" name=\"range_eid\" value=\"$range_eid\">\n";
   echo "<input type=\"hidden\" name=\"keyword\" value=\"$oldkeyword\">\n";
   echo "<input type=\"hidden\" name=\"TABFLAG\" value=\"$TABFLAG\">\n";
   echo "<input type=\"hidden\" name=\"orig\" value=\"$orig\">\n";
   echo "<input type=\"hidden\" name=\"strongflag\" value=\"$strongflag\">\n";
   echo "<input type=\"submit\" name=\"submit1\" value=\"һҳ\">\n";
   echo "</form></center>\n";
 }
  /***** ҳ ****/
  $a=0;
  $poldkeyword=urlencode($oldkeyword);
  echo "<center>ҳΣ&nbsp;&nbsp;";
  for ($recpt=0;$recpt<=$numrow-1;$recpt=$recpt+$PGNUM)
  {
	$a=$a+1;
	if ($recpt!=$PGBEG) //Ǳҳ
	{
	 echo "&nbsp;<a href=\"$PROGNAME?PGBEG={$recpt}&VERSION={$oldv}&keyword={$poldkeyword}&TABFLAG={$TABFLAG}&orig={$orig}&strongflag={$strongflag}&RANGE={$RANGE}&range_bid={$range_bid}&range_eid={$range_eid}\">{$a}</a>&nbsp;\n";
	}
	else echo "&nbsp;<font color=\"red\">{$a}</font>&nbsp;";
  }
  echo "</center>";
   echo "<center><a href=\"$RETURNADD1\">²ѯ</a></center><br>\n";
   if ($stronged)
   {
echo "<hr>\nKJV + Strongs and lexicons were adapted from the Online Bible. It used by permission and are copyrighted by Timnathserah Inc.";
   }

?>
